documentFactory.MultipleDocumentStream

|  | ## Cheshire3 Object Model: Class MultipleDocumentStream

Module documentFactory :: Class MultipleDocumentStream

## Class MultipleDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
                        MultipleDocumentStream

Known Subclasses:
  DirectoryDocumentStream, FtpDocumentStream, HttpDocumentStream, SrbDocumentStream, TarDocumentStream

Instance Methods

__init__(self, session, stream, format, schema=None, codec=None, factory=None)
_fetchStream(self, path)
_fetchName(self, item)
_processFile(self, session, item)
_processFiles(self, session, items, cache=0)
Inherited from `BaseDocumentStream`: `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### __init__(self, session, stream, format, schema=None, codec=None, factory=None) (Constructor) | source code
Overrides: BaseDocumentStream.__init__

### _fetchStream(self, path) | source code

### _fetchName(self, item) | source code

### _processFile(self, session, item) | source code

### _processFiles(self, session, items, cache=0) | source code